@@ -21,16 +21,18 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
  */
 
-#pragma interface
-
 #include <buffy/Consumer.h>
 #include <buffy/SmartPointer.h>
 #include <string>
 #include <vector>
 
+namespace buffy {
+
 class MailFolderImpl : public SmartPointerItem
 {
 public:
+	virtual ~MailFolderImpl() {}
+
 	virtual const std::string& name() const throw () = 0;
 	virtual const std::string& path() const throw () = 0;
 	virtual std::string type() const throw () = 0;
@@ -71,6 +73,7 @@ public:
 	}
 
 //	static void enumerateFoldersSwig(const char* path, Consumer<MailFolder>& cons);
+	static MailFolder accessFolder(const std::string& path);
 	static void enumerateFolders(const std::string& path, Consumer<MailFolder>& cons);
 	static std::vector<MailFolder> enumerateFolders(const std::string& path);
 };
@@ -78,5 +81,7 @@ public:
 typedef Consumer<MailFolder> MailFolderConsumer;
 typedef Filter<MailFolder> MailFolderFilter;
 
+}
+
 // vim:set ts=4 sw=4:
 #endif
