@@ -18,8 +18,6 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
  */
 
-#pragma implementation
-
 #include "MailboxMailFolder.h"
 #include "Exception.h"
 #include "from.h"
@@ -34,9 +32,11 @@
 #include <errno.h>
 
 using namespace std;
+using namespace buffy;
 
 MailboxMailFolder::MailboxMailFolder(const string& path) throw ()
-	: _path(path), _deleted(false)
+	: _path(path), _stat_total(-1), _stat_unread(-1), _stat_new(-1), _stat_flagged(-1),
+	  _mbox_mtime(0), _mbox_size(0), _deleted(false)
 {
 	_name = _path;
 
@@ -58,7 +58,7 @@ MailboxMailFolder::MailboxMailFolder(const string& path) throw ()
 
 MailboxMailFolder::MailboxMailFolder(const string& name, const string& path) throw ()
 	: _name(name), _path(path), _stat_total(-1), _stat_unread(-1), _stat_new(-1), _stat_flagged(-1),
-	  _deleted(false), _mbox_mtime(0) {}
+	  _mbox_mtime(0), _mbox_size(0), _deleted(false) {}
 
 
 static const int BUFFY_NEW		(1);
@@ -116,7 +116,7 @@ bool MailboxMailFolder::changed()
 		return true;
 	}
 
-	return st.st_mtime > _mbox_mtime;
+	return st.st_mtime > _mbox_mtime || st.st_size != _mbox_size;
 }
 
 void MailboxMailFolder::updateStatistics()
@@ -151,6 +151,7 @@ void MailboxMailFolder::updateStatistics()
 		_deleted = false;
 
 	_mbox_mtime = st.st_mtime;
+	_mbox_size = st.st_size;
 
 //	if (!force && (s.st_size == mbox->file_size) && (s.st_mtime == mbox->file_mtime))
 //		return 0;
@@ -256,6 +257,14 @@ static bool isMailbox(const std::string& pathname)
 	return is_from(buf);
 }
 
+MailFolder MailboxMailFolder::accessFolder(const std::string& path)
+{
+	if (isMailbox(path))
+		return MailFolder(new MailboxMailFolder(path));
+	return MailFolder();
+}
+
+
 void MailboxMailFolder::enumerateFolders(const std::string& parent, MailFolderConsumer& cons)
 {
 	// Perform consistency checks on the parent directory
